@@ -35,7 +35,8 @@ use crate::{
     ToString,
     Vec,
 };
-use snarkvm_models::curves::{AffineCurve, Field, One, PairingEngine, PrimeField, ProjectiveCurve, Zero};
+use snarkvm_curves::traits::{AffineCurve, PairingEngine, ProjectiveCurve};
+use snarkvm_fields::{Field, One, PrimeField, Zero};
 
 use core::{convert::TryInto, marker::PhantomData};
 use rand_core::RngCore;
@@ -229,7 +230,7 @@ impl<E: PairingEngine> PolynomialCommitment<E::Fr> for MarlinKZG10<E> {
                     (None, None)
                 } else {
                     let mut sorted_enforced_degree_bounds = enforced_degree_bounds.clone();
-                    sorted_enforced_degree_bounds.sort();
+                    sorted_enforced_degree_bounds.sort_unstable();
 
                     let lowest_shifted_power =
                         max_degree - sorted_enforced_degree_bounds.last().ok_or(Error::EmptyDegreeBounds)?;
